@@ -1,6 +1,6 @@
 /**
  *      @file    pubkey.h
- *      @version 692b1c6 (HEAD -> master, origin/master, origin/HEAD)
+ *      @version 950bba4 (HEAD -> master)
  *
  *      Public and Private key header.
  */
@@ -165,7 +165,8 @@ enum PACKED
     PS_RSA,
     PS_DSA,
     PS_ECC,
-    PS_DH
+    PS_DH,
+    PS_CL_PK /* A public key for CL Library. May contain any key format. */
 };
 
 /** Signature types */
